from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

APIRateLimit: Code
AuthStrategyRuleExisted: Code
AuthTokenForbidden: Code
BadRequest: Code
BatchSizeOverLimit: Code
CMDBNotFindHost: Code
CMDBPluginException: Code
CircuitBreakerRuleExisted: Code
ClientAPINotOpen: Code
DESCRIPTOR: _descriptor.FileDescriptor
DataConflict: Code
DataNoChange: Code
DecryptConfigFileException: Code
EmptyAutToken: Code
EmptyQueryParameter: Code
EmptyRequest: Code
EncryptConfigFileException: Code
ExecuteException: Code
ExecuteSuccess: Code
ExistReleasedConfig: Code
ExistedResource: Code
FaultDetectRuleExisted: Code
HealthCheckNotOpen: Code
HeartbeatExceedLimit: Code
HeartbeatException: Code
HeartbeatOnDisabledIns: Code
HeartbeatTypeNotFound: Code
IPRateLimit: Code
InstanceRegisTimeout: Code
InstanceTooManyRequests: Code
InvalidAuthStrategyID: Code
InvalidAuthStrategyName: Code
InvalidAuthStrategyOwners: Code
InvalidCircuitBreakerBusiness: Code
InvalidCircuitBreakerComment: Code
InvalidCircuitBreakerDepartment: Code
InvalidCircuitBreakerID: Code
InvalidCircuitBreakerName: Code
InvalidCircuitBreakerNamespace: Code
InvalidCircuitBreakerOwners: Code
InvalidCircuitBreakerToken: Code
InvalidCircuitBreakerVersion: Code
InvalidConfigFileContentLength: Code
InvalidConfigFileFormat: Code
InvalidConfigFileGroupName: Code
InvalidConfigFileName: Code
InvalidConfigFileTags: Code
InvalidConfigFileTemplateName: Code
InvalidDiscoverResource: Code
InvalidFaultDetectID: Code
InvalidFaultDetectName: Code
InvalidFaultDetectNamespace: Code
InvalidFluxRateLimitId: Code
InvalidFluxRateLimitQps: Code
InvalidFluxRateLimitSetKey: Code
InvalidInstanceHost: Code
InvalidInstanceID: Code
InvalidInstanceIsolate: Code
InvalidInstanceLogicSet: Code
InvalidInstancePort: Code
InvalidInstanceProtocol: Code
InvalidInstanceVersion: Code
InvalidMeshParameter: Code
InvalidMetadata: Code
InvalidNamespaceName: Code
InvalidNamespaceOwners: Code
InvalidNamespaceToken: Code
InvalidNamespaceWithAlias: Code
InvalidParameter: Code
InvalidPlatformComment: Code
InvalidPlatformDepartment: Code
InvalidPlatformDomain: Code
InvalidPlatformID: Code
InvalidPlatformName: Code
InvalidPlatformOwner: Code
InvalidPlatformQPS: Code
InvalidPlatformToken: Code
InvalidPrincipalType: Code
InvalidQueryInsParameter: Code
InvalidRateLimitAmounts: Code
InvalidRateLimitID: Code
InvalidRateLimitLabels: Code
InvalidRateLimitName: Code
InvalidRequestID: Code
InvalidRoutingID: Code
InvalidRoutingName: Code
InvalidRoutingPolicy: Code
InvalidRoutingPriority: Code
InvalidServiceAlias: Code
InvalidServiceAliasComment: Code
InvalidServiceAliasOwners: Code
InvalidServiceBusiness: Code
InvalidServiceCMDB: Code
InvalidServiceComment: Code
InvalidServiceDepartment: Code
InvalidServiceMetadata: Code
InvalidServiceName: Code
InvalidServiceOwners: Code
InvalidServicePorts: Code
InvalidServiceToken: Code
InvalidUserEmail: Code
InvalidUserGroupID: Code
InvalidUserGroupOwners: Code
InvalidUserID: Code
InvalidUserMobile: Code
InvalidUserName: Code
InvalidUserOwners: Code
InvalidUserPassword: Code
InvalidUserToken: Code
InvalidWatchConfigFileFormat: Code
NamespaceExistedCircuitBreakers: Code
NamespaceExistedConfigGroups: Code
NamespaceExistedMeshResources: Code
NamespaceExistedServices: Code
NoNeedUpdate: Code
NotAllowAliasBindRule: Code
NotAllowAliasCreateInstance: Code
NotAllowAliasCreateRateLimit: Code
NotAllowAliasCreateRouting: Code
NotAllowAliasUpdate: Code
NotAllowBusinessService: Code
NotAllowCreateAliasForAlias: Code
NotAllowDifferentNamespaceBindRule: Code
NotAllowModifyDefaultStrategyPrincipal: Code
NotAllowModifyOwnerDefaultStrategy: Code
NotAllowedAccess: Code
NotFoundAuthStrategyRule: Code
NotFoundCircuitBreaker: Code
NotFoundInstance: Code
NotFoundMasterConfig: Code
NotFoundNamespace: Code
NotFoundOwnerUser: Code
NotFoundPlatform: Code
NotFoundRateLimit: Code
NotFoundResource: Code
NotFoundResourceConfigFile: Code
NotFoundRouting: Code
NotFoundService: Code
NotFoundServiceAlias: Code
NotFoundSourceService: Code
NotFoundTagConfig: Code
NotFoundTagConfigOrService: Code
NotFoundUser: Code
NotFoundUserGroup: Code
OperationRoleForbidden: Code
ParseCircuitBreakerException: Code
ParseException: Code
ParseRateLimitException: Code
ParseRoutingException: Code
ResourcesExistedMesh: Code
SameInstanceRequest: Code
ServiceExistedAlias: Code
ServiceExistedCircuitBreakers: Code
ServiceExistedFluxRateLimits: Code
ServiceExistedInstances: Code
ServiceExistedRateLimits: Code
ServiceExistedRoutings: Code
ServiceSubscribedByMeshes: Code
ServicesExistedMesh: Code
StoreLayerException: Code
SubAccountExisted: Code
TokenDisabled: Code
TokenNotExisted: Code
Unauthorized: Code
Unknown: Code
UserExisted: Code
UserGroupExisted: Code

class Code(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpcapi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import client_pb2 as client__pb2
from ..service_manage import service_pb2 as service__pb2
from ..service_manage import request_pb2 as request__pb2
from ..service_manage import response_pb2 as response__pb2
from ..service_manage import heartbeat_pb2 as heartbeat__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgrpcapi.proto\x12\x02v1\x1a\x0c\x63lient.proto\x1a\rservice.proto\x1a\rrequest.proto\x1a\x0eresponse.proto\x1a\x0fheartbeat.proto2\xe6\x03\n\x0bPolarisGRPC\x12*\n\x0cReportClient\x12\n.v1.Client\x1a\x0c.v1.Response\"\x00\x12\x30\n\x10RegisterInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12\x32\n\x12\x44\x65registerInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12;\n\x08\x44iscover\x12\x13.v1.DiscoverRequest\x1a\x14.v1.DiscoverResponse\"\x00(\x01\x30\x01\x12)\n\tHeartbeat\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12\x45\n\x0e\x42\x61tchHeartbeat\x12\x15.v1.HeartbeatsRequest\x1a\x16.v1.HeartbeatsResponse\"\x00(\x01\x30\x01\x12J\n\x11\x42\x61tchGetHeartbeat\x12\x18.v1.GetHeartbeatsRequest\x1a\x19.v1.GetHeartbeatsResponse\"\x00\x12J\n\x11\x42\x61tchDelHeartbeat\x12\x18.v1.DelHeartbeatsRequest\x1a\x19.v1.DelHeartbeatsResponse\"\x00\x42\x93\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x12PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpcapi_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\022PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _POLARISGRPC._serialized_start=99
  _POLARISGRPC._serialized_end=585
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_file.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63onfig_file.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xa3\x06\n\x0f\x43onfigFileGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfileCount\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x38\n\x08user_ids\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\r \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12,\n\x08\x65\x64itable\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x05owner\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xac\x06\n\nConfigFile\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\t \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0crelease_time\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nrelease_by\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\tencrypted\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0c\x65ncrypt_algo\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"g\n\rConfigFileTag\x12)\n\x03key\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf8\x04\n\x11\x43onfigFileRelease\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf9\x05\n\x18\x43onfigFileReleaseHistory\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04type\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x0c \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xbe\x03\n\x12\x43onfigFileTemplate\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb0\x03\n\x14\x43lientConfigFileInfo\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12)\n\x03md5\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x07 \x03(\x0b\x32\x11.v1.ConfigFileTag\x12-\n\tencrypted\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\npublic_key\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb2\x01\n\x1c\x43lientWatchConfigFileRequest\x12/\n\tclient_ip\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cservice_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x0bwatch_files\x18\x03 \x03(\x0b\x32\x18.v1.ClientConfigFileInfo\"\xa5\x01\n\x17\x43onfigFileExportRequest\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06groups\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05names\x18\x03 \x03(\x0b\x32\x1c.google.protobuf.StringValueB\x8e\x01\n6com.tencent.polaris.specification.api.v1.config.manageB\x0f\x43onfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'config_file_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.tencent.polaris.specification.api.v1.config.manageB\017ConfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manage'
  _CONFIGFILEGROUP._serialized_start=58
  _CONFIGFILEGROUP._serialized_end=861
  _CONFIGFILE._serialized_start=864
  _CONFIGFILE._serialized_end=1676
  _CONFIGFILETAG._serialized_start=1678
  _CONFIGFILETAG._serialized_end=1781
  _CONFIGFILERELEASE._serialized_start=1784
  _CONFIGFILERELEASE._serialized_end=2416
  _CONFIGFILERELEASEHISTORY._serialized_start=2419
  _CONFIGFILERELEASEHISTORY._serialized_end=3180
  _CONFIGFILETEMPLATE._serialized_start=3183
  _CONFIGFILETEMPLATE._serialized_end=3629
  _CLIENTCONFIGFILEINFO._serialized_start=3632
  _CLIENTCONFIGFILEINFO._serialized_end=4064
  _CLIENTWATCHCONFIGFILEREQUEST._serialized_start=4067
  _CLIENTWATCHCONFIGFILEREQUEST._serialized_end=4245
  _CONFIGFILEEXPORTREQUEST._serialized_start=4248
  _CONFIGFILEEXPORTREQUEST._serialized_end=4413
# @@protoc_insertion_point(module_scope)
